@@ -29,10 +29,6 @@ import smtplib
 import socket
 import tempfile
 
-if sys.version_info[0] >= 3:
-    basestring = str
-    unicode = str    
-
 from debian.changelog import Changelog, Version
 from distro_info import DebianDistroInfo, DistroDataOutdated
 
@@ -42,6 +38,11 @@ from ubuntutools.logger import Logger
 from ubuntutools.question import confirmation_prompt, YesNoQuestion
 from ubuntutools import subprocess
 
+if sys.version_info[0] >= 3:
+    basestring = str
+    unicode = str
+
+
 __all__ = [
     'get_debian_srcpkg',
     'get_ubuntu_srcpkg',
@@ -51,6 +52,7 @@ __all__ = [
     'mail_bug',
 ]
 
+
 def _get_srcpkg(distro, name, release):
     if distro == 'debian':
         # Canonicalise release:
@@ -64,33 +66,33 @@ def _get_srcpkg(distro, name, release):
     if not lines:
         lines = list(rmadison(distro, name, suite=release, arch='source'))
         if not lines:
-            raise PackageNotFoundException("'%s' doesn't appear to exist "
-                                           "in %s '%s'"
-                                           % (name, distro.capitalize(),
-                                           release))
+            raise PackageNotFoundException("'%s' doesn't appear to exist in %s '%s'" %
+                                           (name, distro.capitalize(), release))
     pkg = max(lines, key=lambda x: Version(x['version']))
 
     return FakeSPPH(pkg['source'], pkg['version'], pkg['component'], distro)
 
+
 def get_debian_srcpkg(name, release):
     return _get_srcpkg('debian', name, release)
 
+
 def get_ubuntu_srcpkg(name, release):
     return _get_srcpkg('ubuntu', name, release)
 
+
 def need_sponsorship(name, component, release):
     '''
     Ask the user if he has upload permissions for the package or the
     component.
     '''
 
-    val = YesNoQuestion().ask("Do you have upload permissions for the "
-                              "'%s' component or the package '%s' in "
-                              "Ubuntu %s?\n"
-                              "If in doubt answer 'n'."
-                               % (component, name, release), 'no')
+    val = YesNoQuestion().ask("Do you have upload permissions for the '%s' component or "
+                              "the package '%s' in Ubuntu %s?\nIf in doubt answer 'n'." %
+                              (component, name, release), 'no')
     return val == 'no'
 
+
 def check_existing_reports(srcpkg):
     '''
     Point the user to the URL to manually check for duplicate bug reports.
@@ -100,6 +102,7 @@ def check_existing_reports(srcpkg):
           'for duplicate sync requests before continuing.' % srcpkg)
     confirmation_prompt()
 
+
 def get_ubuntu_delta_changelog(srcpkg):
     '''
     Download the Ubuntu changelog and extract the entries since the last sync
@@ -119,6 +122,7 @@ def get_ubuntu_delta_changelog(srcpkg):
 
     return u'\n'.join(delta)
 
+
 def mail_bug(srcpkg, subscribe, status, bugtitle, bugtext, bug_mail_domain,
              keyid, myemailaddr, mailserver_host, mailserver_port,
              mailserver_user, mailserver_pass):
@@ -177,9 +181,11 @@ Content-Type: text/plain; charset=UTF-8
     confirmation_prompt()
 
     # save mail in temporary file
-    backup = tempfile.NamedTemporaryFile(mode='w', delete=False,
-            prefix='requestsync-' + re.sub(r'[^a-zA-Z0-9_-]', '',
-                                           bugtitle.replace(' ', '_')))
+    backup = tempfile.NamedTemporaryFile(
+        mode='w',
+        delete=False,
+        prefix='requestsync-' + re.sub(r'[^a-zA-Z0-9_-]', '', bugtitle.replace(' ', '_'))
+    )
     with backup:
         backup.write(mail)
 
@@ -193,16 +199,30 @@ Content-Type: text/plain; charset=UTF-8
                           mailserver_port)
             s = smtplib.SMTP(mailserver_host, mailserver_port)
             break
-        except socket.error as s:
-            Logger.error('Could not connect to %s:%s: %s (%i)',
-                         mailserver_host, mailserver_port, s[1], s[0])
-            return
         except smtplib.SMTPConnectError as s:
-            Logger.error('Could not connect to %s:%s: %s (%i)',
-                         mailserver_host, mailserver_port, s[1], s[0])
+            try:
+                # py2 path
+                # pylint: disable=unsubscriptable-object
+                Logger.error('Could not connect to %s:%s: %s (%i)',
+                             mailserver_host, mailserver_port, s[1], s[0])
+            except TypeError:
+                # pylint: disable=no-member
+                Logger.error('Could not connect to %s:%s: %s (%i)',
+                             mailserver_host, mailserver_port, s.strerror, s.errno)
             if s.smtp_code == 421:
-                confirmation_prompt(message='This is a temporary error, press '
-                          '[Enter] to retry. Press [Ctrl-C] to abort now.')
+                confirmation_prompt(message='This is a temporary error, press [Enter] '
+                                            'to retry. Press [Ctrl-C] to abort now.')
+        except socket.error as s:
+            try:
+                # py2 path
+                # pylint: disable=unsubscriptable-object
+                Logger.error('Could not connect to %s:%s: %s (%i)',
+                             mailserver_host, mailserver_port, s[1], s[0])
+            except TypeError:
+                # pylint: disable=no-member
+                Logger.error('Could not connect to %s:%s: %s (%i)',
+                             mailserver_host, mailserver_port, s.strerror, s.errno)
+            return
 
     if mailserver_user and mailserver_pass:
         try:
@@ -228,8 +248,8 @@ Content-Type: text/plain; charset=UTF-8
             smtp_code, smtp_message = smtperror.recipients[to]
             Logger.error('Error while sending: %i, %s', smtp_code, smtp_message)
             if smtp_code == 450:
-                confirmation_prompt(message='This is a temporary error, press '
-                          '[Enter] to retry. Press [Ctrl-C] to abort now.')
+                confirmation_prompt(message='This is a temporary error, press [Enter] '
+                                            'to retry. Press [Ctrl-C] to abort now.')
             else:
                 return
         except smtplib.SMTPResponseException as e:
